==> CTF_1_0.zip: Complete_the_formula.py <==
import sys
import numpy as np
import warnings

sys.argv

rand_flag = False
com_flag = False
max_count = -1
disp_help = False
for i in range(1, len(sys.argv)):
    if "/r" == sys.argv[i].replace('--', '-').replace('-', '/').lower():
        rand_flag = True
    if "/c" == sys.argv[i].replace('--', '-').replace('-', '/').lower():
        com_flag = True
    if "/h" == sys.argv[i].replace('--', '-').replace('-', '/').lower() or "/help" ==  sys.argv[i].replace('--', '-').replace('-', '/').lower() or "/?" == sys.argv[i].replace('--', '-').replace('-', '/'):
        disp_help = True
    if sys.argv[i].isdecimal():
        max_count = int(sys.argv[i])
        
if disp_help:
    print("\n\"Complete the formula.\"\n")
    print("This program completes all the formulas\n when you input parameters and a answer.\n")
    print("Command line option")
    print("\"-h\"\t:\tShow help (this option)")
    print("\"-r\"\t:\tRandomize the order of the parameters")
    print("\"-c\"\t:\tMake the operator suitable for the computer")
    print("number\t:\tMaximum number of candidates")
    sys.exit(0)

print("\n\"Complete the formula.\"\n")
print("Please enter the numbers separated by spaces.")
try:
    numbers = list(map(int, input("num1 num2 num3 ... ans:\n").split()))
except Exception:
    print("Not numeric error")
    sys.exit(1)
if 1 < len(numbers):
    ans = numbers.pop()
    par_count = len(numbers)
    if rand_flag:
        numbers.sort()  #(reverse = True)
else:
    sys.exit(1)
print()

min_item_number = 0
for i in range(par_count):
    min_item_number = min_item_number * (par_count + 1) + (i + 1)
if rand_flag:
    max_item_number = 0
    for i in range(par_count - 1, - 1, - 1):
        max_item_number = max_item_number * (par_count + 1) + (i + 1)
else:
    max_item_number = min_item_number
 
def kai(n):
    x = 1
    for i in range(n):
        x *= (i + 1)
    return x

order_array = np.array([[0] * (par_count - 1)] * kai(par_count - 1))
for i in range(par_count - 1):
    order_index = 0
    while order_index < kai(par_count - 1):
        for j in range(par_count - 1 - i):
            for k in range(kai(par_count - 2 - i)): # / kai(par_count - 1 - i)):
                order_array[order_index, i] = j
                order_index = order_index + 1
print("Array 1 creation OK.")

ope_array = np.array([[0] * (par_count - 1)] * (4 ** (par_count - 1)))
for i in range(par_count - 1):
    ope_index = 0
    for j in range(4 ** i):
        for k in range(4):
            for l in range(4 ** (par_count - 2 - i)):
                ope_array[ope_index, i] = k
                ope_index = ope_index + 1
print("Array 2 creation OK.")

def select_all(x):
    n = [False] * par_count
    t = True
    for i in range(len(n) - 1, - 1, - 1):
        y = x % (par_count + 1)
        x //= (par_count + 1)
        for j in range(len(n)):
            if y == j + 1:
                n[j] = True
                break
    for i in range(len(n)):
        if not n[i]:
            t = False
            break
    return t

warnings.filterwarnings("ignore")
print()
print("Calculation started ****************")
par_list_str = ","
for order_number in range(min_item_number, max_item_number + 1):
    if 0 == max_count:
        break
    if select_all(order_number):
        try:
            par = np.array([0] * par_count)
            ope_num = np.array([0] * (par_count - 1))
            cal_str = [""] * par_count
            cal = np.array([0.0] * par_count)
            addition_or_subtraction = np.array([False] * par_count)
            division = np.array([False] * par_count)
            x = order_number
            par_str = ""
            for i in range(par_count - 1, - 1, - 1):
                y = x % (par_count + 1)
                x //= (par_count + 1)
                par[i] = numbers[y - 1]
                par_str += (str(par[i]) + " ")
            par_str += ","
            if "," + par_str + "," in par_list_str:
                continue
            else:
                par_list_str += (par_str + ",")
                ans_str = ","
            for order_index in range(len(order_array)):
                if 0 == max_count:
                    break
                for ope_index in range(len(ope_array)):
                    if 0 == max_count:
                        break
                    for i in range(len(ope_num)):
                        ope_num[i] = ope_array[ope_index, i]
                    for i in range(par_count):
                        cal[i] = par[i]
                        if 0 < cal[i]:
                            cal_str[i] = str(int(cal[i]))
                        else:
                            cal_str[i] = "(" + str(int(cal[i])) + ")"
                        addition_or_subtraction[i] = False
                        division[i] = False
                    count = par_count
                    decorative_string = ""
                    for order in range(par_count - 1):
                        if 0 == max_count:
                            break
                        point = order_array[order_index, order]
                        if 0 == ope_num[point]:
                            cal_str[point] += "+" + cal_str[point + 1]
                            try:
                                cal[point] += cal[point + 1]
                            except Warning:
                                continue
                            addition_or_subtraction[point] = True
                            division[point] = False
                        elif 1 == ope_num[point]:
                            if addition_or_subtraction[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            cal_str[point] += "-" + cal_str[point + 1]
                            try:
                                cal[point] -= cal[point + 1]
                            except Warning:
                                continue
                            addition_or_subtraction[point] = True
                            division[point] = False
                        elif 2 == ope_num[point]:
                            if addition_or_subtraction[point]:
                                cal_str[point] = "(" + cal_str[point] + ")"
                            if addition_or_subtraction[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            if com_flag:
                                cal_str[point] += "*" + cal_str[point + 1]
                            else:
                                cal_str[point] += "×" + cal_str[point + 1]
                            try:
                                cal[point] *= cal[point + 1]
                            except Warning:
                                continue
                            addition_or_subtraction[point] = False
                            division[point] = False
                        else:
                            if addition_or_subtraction[point]:
                                cal_str[point] = "(" + cal_str[point] + ")"
                            if addition_or_subtraction[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            if division[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            if com_flag:
                                cal_str[point] += "/" + cal_str[point + 1]
                            else:
                                cal_str[point] += "÷" + cal_str[point + 1]
                            try:
                                cal[point] /= cal[point + 1]
                            except Warning:
                                continue
                            addition_or_subtraction[point] = False
                            division[point] = True
                            
                        count -= 1
                        for i in range(point + 1, count):
                            cal[i] = cal[i + 1]
                            cal_str[i] = cal_str[i + 1]
                            addition_or_subtraction[i] = addition_or_subtraction[i + 1]
                            division[i] = division[i + 1]
                        for i in range(point, count - 1):
                            ope_num[i] = ope_num[i + 1]

                    if cal[0] == ans:
                        if not "," + cal_str[0] + "," in ans_str:
                            ans_str += (cal_str[0] + ",")
                            print_str = cal_str[0]
                            print_str += " = " + str(ans)
                            print(print_str)
                            if 0 < max_count:
                                max_count -= 1
        except MemoryError:
            print("\t\033[31m--- MemoryError ---\033[0m")
            break
print("Calculation complete ****************")
input("\nPlease press [enter] key.\a\n")
sys.exit(0)

==> CTF_1_1.zip: Complete_the_formula.py <==
import sys
import numpy as np
import warnings

sys.argv

rand_flag = False
com_flag = False
max_count = -1
disp_help = False

print("\n\"Complete the formula.\"    in Python\n")
print("This program completes all the formulas when you input several parameters and one answer.\n")

for i in range(1, len(sys.argv)):
    if "/r" == sys.argv[i].replace('--', '-').replace('-', '/').lower():
        rand_flag = True
    if "/c" == sys.argv[i].replace('--', '-').replace('-', '/').lower():
        com_flag = True
    if "/h" == sys.argv[i].replace('--', '-').replace('-', '/').lower() or "/help" ==  sys.argv[i].replace('--', '-').replace('-', '/').lower() or "/?" == sys.argv[i].replace('--', '-').replace('-', '/'):
        disp_help = True
    if sys.argv[i].isdecimal():
        max_count = int(sys.argv[i])
        
if disp_help:
    print("Command line option")
    print("\"-h\"\t:\tShow help (this option)")
    print("\"-r\"\t:\tRandomize the order of the parameters")
    print("\"-c\"\t:\tMake the operator suitable for the computer")
    print("number\t:\tMaximum number of candidates")
    input("\nPlease press [enter] key.\a\n")
    sys.exit(0)

print("Please enter the numbers separated by spaces.")
try:
    numbers = list(map(int, input("num1 num2 num3 ... ans:\n").split()))
except Exception:
    print("Not numeric error")
    sys.exit(1)
if 2 < len(numbers):
    ans = numbers.pop()
    par_count = len(numbers)
    if rand_flag:
        numbers.sort()  #(reverse = True)
else:
    print()
    print("Three or more numbers are required.")
    input("\nPlease press [enter] key.\a\n")
    sys.exit(1)
print()

min_item_number = 0
for i in range(par_count):
    min_item_number = min_item_number * (par_count + 1) + (i + 1)
if rand_flag:
    max_item_number = 0
    for i in range(par_count - 1, - 1, - 1):
        max_item_number = max_item_number * (par_count + 1) + (i + 1)
else:
    max_item_number = min_item_number
 
def kai(n):
    x = 1
    for i in range(n):
        x *= (i + 1)
    return x

order_array = np.array([[0] * (par_count - 1)] * kai(par_count - 1))
for i in range(par_count - 1):
    order_index = 0
    while order_index < kai(par_count - 1):
        for j in range(par_count - 1 - i):
            for k in range(kai(par_count - 2 - i)): # / kai(par_count - 1 - i)):
                order_array[order_index, i] = j
                order_index = order_index + 1
print("Array 1 creation OK.")

ope_array = np.array([[0] * (par_count - 1)] * (4 ** (par_count - 1)))
for i in range(par_count - 1):
    ope_index = 0
    for j in range(4 ** i):
        for k in range(4):
            for l in range(4 ** (par_count - 2 - i)):
                ope_array[ope_index, i] = k
                ope_index = ope_index + 1
print("Array 2 creation OK.")

def select_all(x):
    n = [False] * par_count
    t = True
    for i in range(len(n) - 1, - 1, - 1):
        y = x % (par_count + 1)
        x //= (par_count + 1)
        for j in range(len(n)):
            if y == j + 1:
                n[j] = True
                break
    for i in range(len(n)):
        if not n[i]:
            t = False
            break
    return t

warnings.filterwarnings("ignore")
print()
print("Calculation started ****************")
par_list_str = ","
for order_number in range(min_item_number, max_item_number + 1):
    if 0 == max_count:
        break
    if select_all(order_number):
        try:
            par = np.array([0] * par_count)
            ope_num = np.array([0] * (par_count - 1))
            cal_str = [""] * par_count
            cal = np.array([0.0] * par_count)
            addition_or_subtraction = np.array([False] * par_count)
            division = np.array([False] * par_count)
            x = order_number
            par_str = ""
            for i in range(par_count - 1, - 1, - 1):
                y = x % (par_count + 1)
                x //= (par_count + 1)
                par[i] = numbers[y - 1]
                par_str += (str(par[i]) + " ")
            par_str += ","
            if "," + par_str + "," in par_list_str:
                continue
            else:
                par_list_str += (par_str + ",")
                ans_str = ","
            for order_index in range(len(order_array)):
                if 0 == max_count:
                    break
                for ope_index in range(len(ope_array)):
                    if 0 == max_count:
                        break
                    for i in range(len(ope_num)):
                        ope_num[i] = ope_array[ope_index, i]
                    for i in range(par_count):
                        cal[i] = par[i]
                        if 0 < cal[i]:
                            cal_str[i] = str(int(cal[i]))
                        else:
                            cal_str[i] = "(" + str(int(cal[i])) + ")"
                        addition_or_subtraction[i] = False
                        division[i] = False
                    count = par_count
#                    decorative_string = ""
                    for order in range(par_count - 1):
                        if 0 == max_count:
                            break
                        point = order_array[order_index, order]
                        if 0 == ope_num[point]:
                            cal_str[point] += "+" + cal_str[point + 1]
                            try:
                                cal[point] += cal[point + 1]
                            except Warning:
                                break
                            addition_or_subtraction[point] = True
                            division[point] = False
                        elif 1 == ope_num[point]:
                            if addition_or_subtraction[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            cal_str[point] += "-" + cal_str[point + 1]
                            try:
                                cal[point] -= cal[point + 1]
                            except Warning:
                                break
                            addition_or_subtraction[point] = True
                            division[point] = False
                        elif 2 == ope_num[point]:
                            if addition_or_subtraction[point]:
                                cal_str[point] = "(" + cal_str[point] + ")"
                            if addition_or_subtraction[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            if com_flag:
                                cal_str[point] += "*" + cal_str[point + 1]
                            else:
                                cal_str[point] += "×" + cal_str[point + 1]
                            try:
                                cal[point] *= cal[point + 1]
                            except Warning:
                                break
                            addition_or_subtraction[point] = False
                            division[point] = False
                        else:
                            if addition_or_subtraction[point]:
                                cal_str[point] = "(" + cal_str[point] + ")"
                            if addition_or_subtraction[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            if division[point + 1]:
                                cal_str[point + 1] = "(" + cal_str[point + 1] + ")"
                            if com_flag:
                                cal_str[point] += "/" + cal_str[point + 1]
                            else:
                                cal_str[point] += "÷" + cal_str[point + 1]
                            try:
                                cal[point] /= cal[point + 1]
                            except Warning:
                                break
                            addition_or_subtraction[point] = False
                            division[point] = True
                            
                        count -= 1
                        for i in range(point + 1, count):
                            cal[i] = cal[i + 1]
                            cal_str[i] = cal_str[i + 1]
                            addition_or_subtraction[i] = addition_or_subtraction[i + 1]
                            division[i] = division[i + 1]
                        for i in range(point, count - 1):
                            ope_num[i] = ope_num[i + 1]
                    if cal[0] == ans and 1 == count:
                        if not "," + cal_str[0] + "," in ans_str:
                            ans_str += (cal_str[0] + ",")
                            print_str = cal_str[0]
                            print_str += " = " + str(ans)
                            print(print_str)
                            if 0 < max_count:
                                max_count -= 1
        except MemoryError:
            print("\t\033[31m--- MemoryError ---\033[0m")
            break
print("Calculation complete ****************")
input("\nPlease press [enter] key.\a\n")
sys.exit(0)
